@@ -1,6 +1,6 @@
 # MIT License
 #
-# Copyright (c) 2021 Templin Konstantin
+# Copyright (c) 2021-2022 Templin Konstantin
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -19,18 +19,21 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-from typing import List, Optional, NamedTuple
+"""TinyDB storage module."""
+
+from typing import List, NamedTuple, Optional
 
 from feijoa.utils.imports import ImportWrapper
 
 with ImportWrapper():
     from tinydb import Query, TinyDB
     from tinydb.table import Document
+    from tinydb.operations import set as tinydb_set
 
-from feijoa.search.space import SearchSpace
 from feijoa.exceptions import DBVersionError, InsertExperimentWithTheExistedId
 from feijoa.models import Experiment
 from feijoa.models.configuration import Configuration
+from feijoa.search.space import SearchSpace
 from feijoa.storages.storage import Storage
 
 __all__ = ["TinyDBStorage"]
@@ -44,6 +47,7 @@ class _Parameter(NamedTuple):
 
 # noinspection PyTypeChecker
 class TinyDBStorage(Storage):
+    """TinyDB storage uses tinydb library."""
 
     __version__ = "0.1.0"
 
@@ -70,6 +74,7 @@ class TinyDBStorage(Storage):
         doc = {
             "name": job.name,
             "id": job.id,
+            "last_optimizer": job.optimizer_name_dsl,
         }
 
         self.jobs_table.insert(doc)
@@ -79,21 +84,36 @@ class TinyDBStorage(Storage):
             kind = p.__class__.__name__
             meta = p.meta
             param_model = {
-                'job_id': job.id,
-                'name': name,
-                'kind': kind,
-                'meta': meta,
+                "job_id": job.id,
+                "name": name,
+                "kind": kind,
+                "meta": meta,
             }
             self.parameters_table.insert(param_model)
 
+    def update_optimizer_name_by_job_id(self, job_id, name):
+        self.jobs_table.update(tinydb_set("last_optimizer", name), Query().id == "John")
+
     def get_search_space_by_job_id(self, job_id) -> SearchSpace:
         parameters = self.parameters_table.search(Query().job_id == job_id)
         pool = list()
         for p in parameters:
-            mod = _Parameter(name=p['name'], kind=p['kind'], meta=p['meta'])
+            mod = _Parameter(name=p["name"], kind=p["kind"], meta=p["meta"])
             pool.append(mod)
         return SearchSpace.from_db_parameters(pool)
 
+    def get_optimizer_name_by_job_id(self, job_id) -> Optional[str]:
+        jobs = self.jobs_table.search(Query().id == job_id)
+
+        if not len(jobs):
+            return None
+
+        assert len(jobs) == 1
+
+        job, *_ = jobs
+
+        return job["optimizer_name_dsl"]
+
     def get_job_id_by_name(self, name) -> Optional[int]:
         jobs = self.jobs_table.search(Query().name == name)
 
@@ -112,7 +132,7 @@ class TinyDBStorage(Storage):
 
     def insert_experiment(self, experiment):
         doc = experiment.dict()
-        doc['requestor'] = experiment.params.requestor
+        doc["requestor"] = experiment.params.requestor
 
         if self.get_experiment(experiment.job_id, experiment.id):
             # TODO (qnbhd): make correct exception
@@ -121,15 +141,16 @@ class TinyDBStorage(Storage):
         self.experiments_table.insert(doc)
 
     def get_experiment(self, job_id, experiment_id):
-        q = self.experiments_table.search((Query().id == experiment_id)
-                                          & (Query().job_id == job_id))
+        q = self.experiments_table.search(
+            (Query().id == experiment_id) & (Query().job_id == job_id)
+        )
 
         if not q:
             return None
 
         exp = q[0]
-        exp['params'] = Configuration(exp['params'], requestor=exp['requestor'])
-        exp.pop('requestor')
+        exp["params"] = Configuration(exp["params"], requestor=exp["requestor"])
+        exp.pop("requestor")
 
         return Experiment(**exp)
 
@@ -141,14 +162,14 @@ class TinyDBStorage(Storage):
         docs = self._get_raw_experiments(job_id)
         experiments = []
         for doc in docs:
-            doc['params'] = Configuration(doc['params'], requestor=doc['requestor'])
+            doc["params"] = Configuration(doc["params"], requestor=doc["requestor"])
             # doc.pop('requestor')
             exp = Experiment(**doc)
             experiments.append(exp)
         return experiments
 
-    def get_experiments_count(self, job) -> int:
-        return len(self.get_experiments_by_job_id(job))
+    def get_experiments_count(self, job_id) -> int:
+        return len(self.get_experiments_by_job_id(job_id))
 
     @property
     def jobs(self):
